@@ -1,22 +1,19 @@
 /*******************************************************************************
  *  BDX: Binary Data eXchange format library
- *  Copyright (C) 1999--2008 Thomas Baier
+ *  Copyright (C) 1999--2009 Thomas Baier
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- *  MA 02110-1301, USA.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  ******************************************************************************/
 
 #ifndef _BDX_H_
@@ -43,8 +40,11 @@ extern "C" {
  * Vtbl version information:
  *
  * 1 ... first interface (bdx_free, bdx_trace, Variant2BDX, BDX2Variant)
+ * 2 ... removed Variant2BDX, BDX2Variant
  */
-#define BDX_VTBL_VERSION 1
+#define BDX_VTBL_VERSION_1 1
+#define BDX_VTBL_VERSION_2 2
+#define BDX_VTBL_VERSION BDX_VTBL_VERSION_2
 
 
 #if 1
@@ -158,7 +158,7 @@ typedef int (SYSCALL *BDX_BDX2VARIANT) (struct _BDX_Data* bdx,VARIANT* var);
 #endif
 
 /* function table for BDX library */
-typedef struct _BDX_Vtbl
+struct _BDX_Vtbl1
 {
   BDX_FREE bdx_free;
   BDX_TRACE bdx_trace;
@@ -166,7 +166,14 @@ typedef struct _BDX_Vtbl
   BDX_VARIANT2BDX Variant2BDX;
   BDX_BDX2VARIANT BDX2Variant;
 #endif
-} BDX_Vtbl;
+};
+struct _BDX_Vtbl2
+{
+  BDX_FREE bdx_free;
+  BDX_TRACE bdx_trace;
+};
+
+typedef struct _BDX_Vtbl2 BDX_Vtbl;
 
 /* entry point: retrieve a proxy object with a given version */
 typedef int (SYSCALL* BDX_GET_VTBL) (BDX_Vtbl**,unsigned long);
